# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_cloud.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_client_objects_pb2 as steammessages__client__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19steammessages_cloud.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x0b\x65nums.proto\x1a\"steammessages_client_objects.proto\"=\n(CCloud_ClientLogUploadCheck_Notification\x12\x11\n\tclient_id\x18\x01 \x01(\x04\"T\n+CCloud_ClientLogUploadComplete_Notification\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x12\n\nrequest_id\x18\x02 \x01(\x04\"\xec\x01\n\x1e\x43\x43loud_BeginHTTPUpload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08\x66ile_sha\x18\x04 \x01(\t\x12\x11\n\tis_public\x18\x05 \x01(\x08\x12\x19\n\x11platforms_to_sync\x18\x06 \x03(\t\x12\x1d\n\x15request_headers_names\x18\x07 \x03(\t\x12\x1e\n\x16request_headers_values\x18\x08 \x03(\t\x12\x17\n\x0fupload_batch_id\x18\t \x01(\x04\"\xed\x01\n\x1f\x43\x43loud_BeginHTTPUpload_Response\x12\r\n\x05ugcid\x18\x01 \x01(\x06\x12\x11\n\ttimestamp\x18\x02 \x01(\x07\x12\x10\n\x08url_host\x18\x03 \x01(\t\x12\x10\n\x08url_path\x18\x04 \x01(\t\x12\x11\n\tuse_https\x18\x05 \x01(\x08\x12\x45\n\x0frequest_headers\x18\x06 \x03(\x0b\x32,.CCloud_BeginHTTPUpload_Response.HTTPHeaders\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"p\n\x1f\x43\x43loud_CommitHTTPUpload_Request\x12\x1a\n\x12transfer_succeeded\x18\x01 \x01(\x08\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x10\n\x08\x66ile_sha\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\":\n CCloud_CommitHTTPUpload_Response\x12\x16\n\x0e\x66ile_committed\x18\x01 \x01(\x08\"{\n\x1d\x43\x43loud_BeginUGCUpload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08\x66ile_sha\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x05 \x01(\t\"\xc7\x02\n\x1e\x43\x43loud_BeginUGCUpload_Response\x12Z\n\x0estorage_system\x18\x01 \x01(\x0e\x32\x1c.EPublishedFileStorageSystem:$k_EPublishedFileStorageSystemInvalid\x12\r\n\x05ugcid\x18\x02 \x01(\x06\x12\x11\n\ttimestamp\x18\x03 \x01(\x07\x12\x10\n\x08url_host\x18\x04 \x01(\t\x12\x10\n\x08url_path\x18\x05 \x01(\t\x12\x11\n\tuse_https\x18\x06 \x01(\x08\x12\x44\n\x0frequest_headers\x18\x07 \x03(\x0b\x32+.CCloud_BeginUGCUpload_Response.HTTPHeaders\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Z\n\x1e\x43\x43loud_CommitUGCUpload_Request\x12\x1a\n\x12transfer_succeeded\x18\x01 \x01(\x08\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\r\n\x05ugcid\x18\x03 \x01(\x06\"9\n\x1f\x43\x43loud_CommitUGCUpload_Response\x12\x16\n\x0e\x66ile_committed\x18\x01 \x01(\x08\"=\n\x1d\x43\x43loud_GetFileDetails_Request\x12\r\n\x05ugcid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"\xc9\x01\n\x0f\x43\x43loud_UserFile\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\r\n\x05ugcid\x18\x02 \x01(\x04\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12\x11\n\tfile_size\x18\x05 \x01(\r\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x07 \x01(\x06\x12\r\n\x05\x66lags\x18\x08 \x01(\r\x12\x19\n\x11platforms_to_sync\x18\t \x03(\t\x12\x10\n\x08\x66ile_sha\x18\n \x01(\t\"C\n\x1e\x43\x43loud_GetFileDetails_Response\x12!\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x10.CCloud_UserFile\"p\n!CCloud_EnumerateUserFiles_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x18\n\x10\x65xtended_details\x18\x02 \x01(\x08\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x13\n\x0bstart_index\x18\x04 \x01(\r\"Z\n\"CCloud_EnumerateUserFiles_Response\x12\x1f\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x10.CCloud_UserFile\x12\x13\n\x0btotal_files\x18\x02 \x01(\r\"Q\n\x15\x43\x43loud_Delete_Request\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x17\n\x0fupload_batch_id\x18\x03 \x01(\x04\"\x18\n\x16\x43\x43loud_Delete_Response\"\'\n%CCloud_GetClientEncryptionKey_Request\"B\n&CCloud_GetClientEncryptionKey_Response\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0b\n\x03\x63rc\x18\x02 \x01(\x05\"\xaa\x01\n\x1d\x43\x43loud_CDNReport_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x18\n\x10http_status_code\x18\x04 \x01(\r\x12\x16\n\x0e\x65xpected_bytes\x18\x05 \x01(\x04\x12\x16\n\x0ereceived_bytes\x18\x06 \x01(\x04\x12\x10\n\x08\x64uration\x18\x07 \x01(\r\"\x90\x03\n1CCloud_ExternalStorageTransferReport_Notification\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tis_upload\x18\x03 \x01(\x08\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x18\n\x10http_status_code\x18\x05 \x01(\r\x12\x16\n\x0e\x62ytes_expected\x18\x06 \x01(\x04\x12\x14\n\x0c\x62ytes_actual\x18\x07 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x08 \x01(\r\x12\x0e\n\x06\x63\x65llid\x18\t \x01(\r\x12\x0f\n\x07proxied\x18\n \x01(\x08\x12\x12\n\nipv6_local\x18\x0b \x01(\x08\x12\x13\n\x0bipv6_remote\x18\x0c \x01(\x08\x12\x1a\n\x12time_to_connect_ms\x18\r \x01(\r\x12\x1b\n\x13time_to_send_req_ms\x18\x0e \x01(\r\x12\x1d\n\x15time_to_first_byte_ms\x18\x0f \x01(\r\x12\x1c\n\x14time_to_last_byte_ms\x18\x10 \x01(\r\"\xa4\x01\n\"CCloud_BeginAppUploadBatch_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x14\n\x0cmachine_name\x18\x02 \x01(\t\x12\x17\n\x0f\x66iles_to_upload\x18\x03 \x03(\t\x12\x17\n\x0f\x66iles_to_delete\x18\x04 \x03(\t\x12\x11\n\tclient_id\x18\x05 \x01(\x04\x12\x14\n\x0c\x61pp_build_id\x18\x06 \x01(\x04\"R\n#CCloud_BeginAppUploadBatch_Response\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\x04\x12\x19\n\x11\x61pp_change_number\x18\x04 \x01(\x04\"d\n*CCloud_CompleteAppUploadBatch_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61tch_id\x18\x02 \x01(\x04\x12\x15\n\rbatch_eresult\x18\x03 \x01(\r\"_\n%CCloud_CompleteAppUploadBatch_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61tch_id\x18\x02 \x01(\x04\x12\x15\n\rbatch_eresult\x18\x03 \x01(\r\"(\n&CCloud_CompleteAppUploadBatch_Response\"\xaf\x02\n$CCloud_ClientBeginFileUpload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x15\n\rraw_file_size\x18\x03 \x01(\r\x12\x10\n\x08\x66ile_sha\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x10\n\x08\x66ilename\x18\x06 \x01(\t\x12%\n\x11platforms_to_sync\x18\x07 \x01(\r:\n4294967295\x12\x0f\n\x07\x63\x65ll_id\x18\t \x01(\r\x12\x13\n\x0b\x63\x61n_encrypt\x18\n \x01(\x08\x12\x16\n\x0eis_shared_file\x18\x0b \x01(\x08\x12\x18\n\x10\x64\x65precated_realm\x18\x0c \x01(\r\x12\x17\n\x0fupload_batch_id\x18\r \x01(\x04\"\xc5\x02\n!ClientCloudFileUploadBlockDetails\x12\x10\n\x08url_host\x18\x01 \x01(\t\x12\x10\n\x08url_path\x18\x02 \x01(\t\x12\x11\n\tuse_https\x18\x03 \x01(\x08\x12\x13\n\x0bhttp_method\x18\x04 \x01(\x05\x12G\n\x0frequest_headers\x18\x05 \x03(\x0b\x32..ClientCloudFileUploadBlockDetails.HTTPHeaders\x12\x14\n\x0c\x62lock_offset\x18\x06 \x01(\x04\x12\x14\n\x0c\x62lock_length\x18\x07 \x01(\r\x12\x1a\n\x12\x65xplicit_body_data\x18\x08 \x01(\x0c\x12\x17\n\x0fmay_parallelize\x18\t \x01(\x08\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"y\n%CCloud_ClientBeginFileUpload_Response\x12\x14\n\x0c\x65ncrypt_file\x18\x01 \x01(\x08\x12:\n\x0e\x62lock_requests\x18\x02 \x03(\x0b\x32\".ClientCloudFileUploadBlockDetails\"v\n%CCloud_ClientCommitFileUpload_Request\x12\x1a\n\x12transfer_succeeded\x18\x01 \x01(\x08\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x10\n\x08\x66ile_sha\x18\x03 \x01(\x0c\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\"@\n&CCloud_ClientCommitFileUpload_Response\x12\x16\n\x0e\x66ile_committed\x18\x01 \x01(\x08\"h\n!CCloud_ClientFileDownload_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\r\n\x05realm\x18\x03 \x01(\r\x12\x13\n\x0b\x66orce_proxy\x18\x04 \x01(\x08\"\xdf\x02\n\"CCloud_ClientFileDownload_Response\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x15\n\rraw_file_size\x18\x03 \x01(\r\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x1a\n\x12is_explicit_delete\x18\x06 \x01(\x08\x12\x10\n\x08url_host\x18\x07 \x01(\t\x12\x10\n\x08url_path\x18\x08 \x01(\t\x12\x11\n\tuse_https\x18\t \x01(\x08\x12H\n\x0frequest_headers\x18\n \x03(\x0b\x32/.CCloud_ClientFileDownload_Response.HTTPHeaders\x12\x11\n\tencrypted\x18\x0b \x01(\x08\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x1f\x43\x43loud_ClientDeleteFile_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x1a\n\x12is_explicit_delete\x18\x03 \x01(\x08\x12\x17\n\x0fupload_batch_id\x18\x04 \x01(\x04\"\"\n CCloud_ClientDeleteFile_Response\"X\n,CCloud_ClientConflictResolution_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11\x63hose_local_files\x18\x02 \x01(\x08\"R\n#CCloud_GetAppFileChangelist_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x1c\n\x14synced_change_number\x18\x02 \x01(\x04\"\x8f\x02\n\x12\x43\x43loud_AppFileInfo\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x10\n\x08sha_file\x18\x02 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x03 \x01(\x04\x12\x15\n\rraw_file_size\x18\x04 \x01(\r\x12W\n\rpersist_state\x18\x05 \x01(\x0e\x32\x1a.ECloudStoragePersistState:$k_ECloudStoragePersistStatePersisted\x12\x19\n\x11platforms_to_sync\x18\x06 \x01(\r\x12\x19\n\x11path_prefix_index\x18\x07 \x01(\r\x12\x1a\n\x12machine_name_index\x18\x08 \x01(\r\"\xc7\x01\n$CCloud_GetAppFileChangelist_Response\x12\x1d\n\x15\x63urrent_change_number\x18\x01 \x01(\x04\x12\"\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x13.CCloud_AppFileInfo\x12\x15\n\ris_only_delta\x18\x03 \x01(\x08\x12\x15\n\rpath_prefixes\x18\x04 \x03(\t\x12\x15\n\rmachine_names\x18\x05 \x03(\t\x12\x17\n\x0f\x61pp_buildid_hwm\x18\x06 \x01(\x04\"x\n CCloud_AppSessionSuspend_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tclient_id\x18\x02 \x01(\x04\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x1c\n\x14\x63loud_sync_completed\x18\x04 \x01(\x08\"#\n!CCloud_AppSessionSuspend_Response\"C\n\x1f\x43\x43loud_AppSessionResume_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tclient_id\x18\x02 \x01(\x04\"\"\n CCloud_AppSessionResume_Response\"\xa1\x01\n\x1e\x43\x43loud_AppLaunchIntent_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tclient_id\x18\x02 \x01(\x04\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12!\n\x19ignore_pending_operations\x18\x04 \x01(\x08\x12\x0f\n\x07os_type\x18\x05 \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\x05\"d\n\x1f\x43\x43loud_AppLaunchIntent_Response\x12\x41\n\x19pending_remote_operations\x18\x01 \x03(\x0b\x32\x1e.CCloud_PendingRemoteOperation\"|\n#CCloud_AppExitSyncDone_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tclient_id\x18\x02 \x01(\x04\x12\x19\n\x11uploads_completed\x18\x03 \x01(\x08\x12\x18\n\x10uploads_required\x18\x04 \x01(\x08\"6\n%CCloud_ClientGetAppQuotaUsage_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\x86\x01\n&CCloud_ClientGetAppQuotaUsage_Response\x12\x16\n\x0e\x65xisting_files\x18\x01 \x01(\r\x12\x16\n\x0e\x65xisting_bytes\x18\x02 \x01(\x04\x12\x15\n\rmax_num_files\x18\x03 \x01(\r\x12\x15\n\rmax_num_bytes\x18\x04 \x01(\x04\"S\n\'CCloud_AppCloudStateChange_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x19\n\x11\x61pp_change_number\x18\x02 \x01(\x04\"@\n*CCloud_ClientLogUploadRequest_Notification\x12\x12\n\nrequest_id\x18\x01 \x01(\x04\x32\xb2\x12\n\x05\x43loud\x12N\n\x14\x43lientLogUploadCheck\x12).CCloud_ClientLogUploadCheck_Notification\x1a\x0b.NoResponse\x12T\n\x17\x43lientLogUploadComplete\x12,.CCloud_ClientLogUploadComplete_Notification\x1a\x0b.NoResponse\x12T\n\x0f\x42\x65ginHTTPUpload\x12\x1f.CCloud_BeginHTTPUpload_Request\x1a .CCloud_BeginHTTPUpload_Response\x12W\n\x10\x43ommitHTTPUpload\x12 .CCloud_CommitHTTPUpload_Request\x1a!.CCloud_CommitHTTPUpload_Response\x12Q\n\x0e\x42\x65ginUGCUpload\x12\x1e.CCloud_BeginUGCUpload_Request\x1a\x1f.CCloud_BeginUGCUpload_Response\x12T\n\x0f\x43ommitUGCUpload\x12\x1f.CCloud_CommitUGCUpload_Request\x1a .CCloud_CommitUGCUpload_Response\x12Q\n\x0eGetFileDetails\x12\x1e.CCloud_GetFileDetails_Request\x1a\x1f.CCloud_GetFileDetails_Response\x12]\n\x12\x45numerateUserFiles\x12\".CCloud_EnumerateUserFiles_Request\x1a#.CCloud_EnumerateUserFiles_Response\x12\x39\n\x06\x44\x65lete\x12\x16.CCloud_Delete_Request\x1a\x17.CCloud_Delete_Response\x12i\n\x16GetClientEncryptionKey\x12&.CCloud_GetClientEncryptionKey_Request\x1a\'.CCloud_GetClientEncryptionKey_Response\x12\x38\n\tCDNReport\x12\x1e.CCloud_CDNReport_Notification\x1a\x0b.NoResponse\x12`\n\x1d\x45xternalStorageTransferReport\x12\x32.CCloud_ExternalStorageTransferReport_Notification\x1a\x0b.NoResponse\x12`\n\x13\x42\x65ginAppUploadBatch\x12#.CCloud_BeginAppUploadBatch_Request\x1a$.CCloud_BeginAppUploadBatch_Response\x12R\n\x16\x43ompleteAppUploadBatch\x12+.CCloud_CompleteAppUploadBatch_Notification\x1a\x0b.NoResponse\x12q\n\x1e\x43ompleteAppUploadBatchBlocking\x12&.CCloud_CompleteAppUploadBatch_Request\x1a\'.CCloud_CompleteAppUploadBatch_Response\x12\x66\n\x15\x43lientBeginFileUpload\x12%.CCloud_ClientBeginFileUpload_Request\x1a&.CCloud_ClientBeginFileUpload_Response\x12i\n\x16\x43lientCommitFileUpload\x12&.CCloud_ClientCommitFileUpload_Request\x1a\'.CCloud_ClientCommitFileUpload_Response\x12]\n\x12\x43lientFileDownload\x12\".CCloud_ClientFileDownload_Request\x1a#.CCloud_ClientFileDownload_Response\x12W\n\x10\x43lientDeleteFile\x12 .CCloud_ClientDeleteFile_Request\x1a!.CCloud_ClientDeleteFile_Response\x12V\n\x18\x43lientConflictResolution\x12-.CCloud_ClientConflictResolution_Notification\x1a\x0b.NoResponse\x12\x63\n\x14GetAppFileChangelist\x12$.CCloud_GetAppFileChangelist_Request\x1a%.CCloud_GetAppFileChangelist_Response\x12Z\n\x11SuspendAppSession\x12!.CCloud_AppSessionSuspend_Request\x1a\".CCloud_AppSessionSuspend_Response\x12W\n\x10ResumeAppSession\x12 .CCloud_AppSessionResume_Request\x1a!.CCloud_AppSessionResume_Response\x12Z\n\x15SignalAppLaunchIntent\x12\x1f.CCloud_AppLaunchIntent_Request\x1a .CCloud_AppLaunchIntent_Response\x12J\n\x15SignalAppExitSyncDone\x12$.CCloud_AppExitSyncDone_Notification\x1a\x0b.NoResponse\x12i\n\x16\x43lientGetAppQuotaUsage\x12&.CCloud_ClientGetAppQuotaUsage_Request\x1a\'.CCloud_ClientGetAppQuotaUsage_Response2\xb6\x01\n\x0b\x43loudClient\x12M\n\x14NotifyAppStateChange\x12(.CCloud_AppCloudStateChange_Notification\x1a\x0b.NoResponse\x12R\n\x16\x43lientLogUploadRequest\x12+.CCloud_ClientLogUploadRequest_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_cloud_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CLOUDCLIENT._options = None
  _CLOUDCLIENT._serialized_options = b'\300\265\030\002'
  _CCLOUD_CLIENTLOGUPLOADCHECK_NOTIFICATION._serialized_start=138
  _CCLOUD_CLIENTLOGUPLOADCHECK_NOTIFICATION._serialized_end=199
  _CCLOUD_CLIENTLOGUPLOADCOMPLETE_NOTIFICATION._serialized_start=201
  _CCLOUD_CLIENTLOGUPLOADCOMPLETE_NOTIFICATION._serialized_end=285
  _CCLOUD_BEGINHTTPUPLOAD_REQUEST._serialized_start=288
  _CCLOUD_BEGINHTTPUPLOAD_REQUEST._serialized_end=524
  _CCLOUD_BEGINHTTPUPLOAD_RESPONSE._serialized_start=527
  _CCLOUD_BEGINHTTPUPLOAD_RESPONSE._serialized_end=764
  _CCLOUD_BEGINHTTPUPLOAD_RESPONSE_HTTPHEADERS._serialized_start=722
  _CCLOUD_BEGINHTTPUPLOAD_RESPONSE_HTTPHEADERS._serialized_end=764
  _CCLOUD_COMMITHTTPUPLOAD_REQUEST._serialized_start=766
  _CCLOUD_COMMITHTTPUPLOAD_REQUEST._serialized_end=878
  _CCLOUD_COMMITHTTPUPLOAD_RESPONSE._serialized_start=880
  _CCLOUD_COMMITHTTPUPLOAD_RESPONSE._serialized_end=938
  _CCLOUD_BEGINUGCUPLOAD_REQUEST._serialized_start=940
  _CCLOUD_BEGINUGCUPLOAD_REQUEST._serialized_end=1063
  _CCLOUD_BEGINUGCUPLOAD_RESPONSE._serialized_start=1066
  _CCLOUD_BEGINUGCUPLOAD_RESPONSE._serialized_end=1393
  _CCLOUD_BEGINUGCUPLOAD_RESPONSE_HTTPHEADERS._serialized_start=722
  _CCLOUD_BEGINUGCUPLOAD_RESPONSE_HTTPHEADERS._serialized_end=764
  _CCLOUD_COMMITUGCUPLOAD_REQUEST._serialized_start=1395
  _CCLOUD_COMMITUGCUPLOAD_REQUEST._serialized_end=1485
  _CCLOUD_COMMITUGCUPLOAD_RESPONSE._serialized_start=1487
  _CCLOUD_COMMITUGCUPLOAD_RESPONSE._serialized_end=1544
  _CCLOUD_GETFILEDETAILS_REQUEST._serialized_start=1546
  _CCLOUD_GETFILEDETAILS_REQUEST._serialized_end=1607
  _CCLOUD_USERFILE._serialized_start=1610
  _CCLOUD_USERFILE._serialized_end=1811
  _CCLOUD_GETFILEDETAILS_RESPONSE._serialized_start=1813
  _CCLOUD_GETFILEDETAILS_RESPONSE._serialized_end=1880
  _CCLOUD_ENUMERATEUSERFILES_REQUEST._serialized_start=1882
  _CCLOUD_ENUMERATEUSERFILES_REQUEST._serialized_end=1994
  _CCLOUD_ENUMERATEUSERFILES_RESPONSE._serialized_start=1996
  _CCLOUD_ENUMERATEUSERFILES_RESPONSE._serialized_end=2086
  _CCLOUD_DELETE_REQUEST._serialized_start=2088
  _CCLOUD_DELETE_REQUEST._serialized_end=2169
  _CCLOUD_DELETE_RESPONSE._serialized_start=2171
  _CCLOUD_DELETE_RESPONSE._serialized_end=2195
  _CCLOUD_GETCLIENTENCRYPTIONKEY_REQUEST._serialized_start=2197
  _CCLOUD_GETCLIENTENCRYPTIONKEY_REQUEST._serialized_end=2236
  _CCLOUD_GETCLIENTENCRYPTIONKEY_RESPONSE._serialized_start=2238
  _CCLOUD_GETCLIENTENCRYPTIONKEY_RESPONSE._serialized_end=2304
  _CCLOUD_CDNREPORT_NOTIFICATION._serialized_start=2307
  _CCLOUD_CDNREPORT_NOTIFICATION._serialized_end=2477
  _CCLOUD_EXTERNALSTORAGETRANSFERREPORT_NOTIFICATION._serialized_start=2480
  _CCLOUD_EXTERNALSTORAGETRANSFERREPORT_NOTIFICATION._serialized_end=2880
  _CCLOUD_BEGINAPPUPLOADBATCH_REQUEST._serialized_start=2883
  _CCLOUD_BEGINAPPUPLOADBATCH_REQUEST._serialized_end=3047
  _CCLOUD_BEGINAPPUPLOADBATCH_RESPONSE._serialized_start=3049
  _CCLOUD_BEGINAPPUPLOADBATCH_RESPONSE._serialized_end=3131
  _CCLOUD_COMPLETEAPPUPLOADBATCH_NOTIFICATION._serialized_start=3133
  _CCLOUD_COMPLETEAPPUPLOADBATCH_NOTIFICATION._serialized_end=3233
  _CCLOUD_COMPLETEAPPUPLOADBATCH_REQUEST._serialized_start=3235
  _CCLOUD_COMPLETEAPPUPLOADBATCH_REQUEST._serialized_end=3330
  _CCLOUD_COMPLETEAPPUPLOADBATCH_RESPONSE._serialized_start=3332
  _CCLOUD_COMPLETEAPPUPLOADBATCH_RESPONSE._serialized_end=3372
  _CCLOUD_CLIENTBEGINFILEUPLOAD_REQUEST._serialized_start=3375
  _CCLOUD_CLIENTBEGINFILEUPLOAD_REQUEST._serialized_end=3678
  _CLIENTCLOUDFILEUPLOADBLOCKDETAILS._serialized_start=3681
  _CLIENTCLOUDFILEUPLOADBLOCKDETAILS._serialized_end=4006
  _CLIENTCLOUDFILEUPLOADBLOCKDETAILS_HTTPHEADERS._serialized_start=722
  _CLIENTCLOUDFILEUPLOADBLOCKDETAILS_HTTPHEADERS._serialized_end=764
  _CCLOUD_CLIENTBEGINFILEUPLOAD_RESPONSE._serialized_start=4008
  _CCLOUD_CLIENTBEGINFILEUPLOAD_RESPONSE._serialized_end=4129
  _CCLOUD_CLIENTCOMMITFILEUPLOAD_REQUEST._serialized_start=4131
  _CCLOUD_CLIENTCOMMITFILEUPLOAD_REQUEST._serialized_end=4249
  _CCLOUD_CLIENTCOMMITFILEUPLOAD_RESPONSE._serialized_start=4251
  _CCLOUD_CLIENTCOMMITFILEUPLOAD_RESPONSE._serialized_end=4315
  _CCLOUD_CLIENTFILEDOWNLOAD_REQUEST._serialized_start=4317
  _CCLOUD_CLIENTFILEDOWNLOAD_REQUEST._serialized_end=4421
  _CCLOUD_CLIENTFILEDOWNLOAD_RESPONSE._serialized_start=4424
  _CCLOUD_CLIENTFILEDOWNLOAD_RESPONSE._serialized_end=4775
  _CCLOUD_CLIENTFILEDOWNLOAD_RESPONSE_HTTPHEADERS._serialized_start=722
  _CCLOUD_CLIENTFILEDOWNLOAD_RESPONSE_HTTPHEADERS._serialized_end=764
  _CCLOUD_CLIENTDELETEFILE_REQUEST._serialized_start=4777
  _CCLOUD_CLIENTDELETEFILE_REQUEST._serialized_end=4896
  _CCLOUD_CLIENTDELETEFILE_RESPONSE._serialized_start=4898
  _CCLOUD_CLIENTDELETEFILE_RESPONSE._serialized_end=4932
  _CCLOUD_CLIENTCONFLICTRESOLUTION_NOTIFICATION._serialized_start=4934
  _CCLOUD_CLIENTCONFLICTRESOLUTION_NOTIFICATION._serialized_end=5022
  _CCLOUD_GETAPPFILECHANGELIST_REQUEST._serialized_start=5024
  _CCLOUD_GETAPPFILECHANGELIST_REQUEST._serialized_end=5106
  _CCLOUD_APPFILEINFO._serialized_start=5109
  _CCLOUD_APPFILEINFO._serialized_end=5380
  _CCLOUD_GETAPPFILECHANGELIST_RESPONSE._serialized_start=5383
  _CCLOUD_GETAPPFILECHANGELIST_RESPONSE._serialized_end=5582
  _CCLOUD_APPSESSIONSUSPEND_REQUEST._serialized_start=5584
  _CCLOUD_APPSESSIONSUSPEND_REQUEST._serialized_end=5704
  _CCLOUD_APPSESSIONSUSPEND_RESPONSE._serialized_start=5706
  _CCLOUD_APPSESSIONSUSPEND_RESPONSE._serialized_end=5741
  _CCLOUD_APPSESSIONRESUME_REQUEST._serialized_start=5743
  _CCLOUD_APPSESSIONRESUME_REQUEST._serialized_end=5810
  _CCLOUD_APPSESSIONRESUME_RESPONSE._serialized_start=5812
  _CCLOUD_APPSESSIONRESUME_RESPONSE._serialized_end=5846
  _CCLOUD_APPLAUNCHINTENT_REQUEST._serialized_start=5849
  _CCLOUD_APPLAUNCHINTENT_REQUEST._serialized_end=6010
  _CCLOUD_APPLAUNCHINTENT_RESPONSE._serialized_start=6012
  _CCLOUD_APPLAUNCHINTENT_RESPONSE._serialized_end=6112
  _CCLOUD_APPEXITSYNCDONE_NOTIFICATION._serialized_start=6114
  _CCLOUD_APPEXITSYNCDONE_NOTIFICATION._serialized_end=6238
  _CCLOUD_CLIENTGETAPPQUOTAUSAGE_REQUEST._serialized_start=6240
  _CCLOUD_CLIENTGETAPPQUOTAUSAGE_REQUEST._serialized_end=6294
  _CCLOUD_CLIENTGETAPPQUOTAUSAGE_RESPONSE._serialized_start=6297
  _CCLOUD_CLIENTGETAPPQUOTAUSAGE_RESPONSE._serialized_end=6431
  _CCLOUD_APPCLOUDSTATECHANGE_NOTIFICATION._serialized_start=6433
  _CCLOUD_APPCLOUDSTATECHANGE_NOTIFICATION._serialized_end=6516
  _CCLOUD_CLIENTLOGUPLOADREQUEST_NOTIFICATION._serialized_start=6518
  _CCLOUD_CLIENTLOGUPLOADREQUEST_NOTIFICATION._serialized_end=6582
  _CLOUD._serialized_start=6585
  _CLOUD._serialized_end=8939
  _CLOUDCLIENT._serialized_start=8942
  _CLOUDCLIENT._serialized_end=9124
_builder.BuildServices(DESCRIPTOR, 'steammessages_cloud_pb2', globals())
# @@protoc_insertion_point(module_scope)
